import { Zone, ZoneFormData } from '../types/zone';

const API_BASE = 'http://localhost:3001/api';

export const api = {
  async getZones(): Promise<Zone[]> {
    const response = await fetch(`${API_BASE}/zones`);
    if (!response.ok) throw new Error('Failed to fetch zones');
    return response.json();
  },

  async getZone(id: number): Promise<Zone> {
    const response = await fetch(`${API_BASE}/zones/${id}`);
    if (!response.ok) throw new Error('Failed to fetch zone');
    return response.json();
  },

  async createZone(data: ZoneFormData): Promise<Zone> {
    const formData = new FormData();
    formData.append('name', data.name);
    formData.append('intervalDays', data.intervalDays.toString());
    formData.append('area', data.area.toString());
    if (data.image) {
      formData.append('image', data.image);
    }

    const response = await fetch(`${API_BASE}/zones`, {
      method: 'POST',
      body: formData,
    });
    if (!response.ok) throw new Error('Failed to create zone');
    return response.json();
  },

  async updateZone(id: number, data: ZoneFormData): Promise<Zone> {
    const formData = new FormData();
    formData.append('name', data.name);
    formData.append('intervalDays', data.intervalDays.toString());
    formData.append('lastMowedDate', data.lastMowedDate);
    formData.append('area', data.area.toString());
    if (data.image) {
      formData.append('image', data.image);
    }

    const response = await fetch(`${API_BASE}/zones/${id}`, {
      method: 'PUT',
      body: formData,
    });
    if (!response.ok) throw new Error('Failed to update zone');
    return response.json();
  },

  async deleteZone(id: number): Promise<void> {
    const response = await fetch(`${API_BASE}/zones/${id}`, {
      method: 'DELETE',
    });
    if (!response.ok) throw new Error('Failed to delete zone');
  },

  async markAsMowed(id: number): Promise<Zone> {
    const response = await fetch(`${API_BASE}/zones/${id}/mow`, {
      method: 'POST',
    });
    if (!response.ok) throw new Error('Failed to mark as mowed');
    return response.json();
  },
};